<?php

namespace Drupal\emergya\Services;


use Drupal\Component\Serialization\Json;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\group\Entity\GroupInterface;
use Drupal\user\Entity\Role;
use Drupal\user\Entity\User;
use Drupal\user\UserInterface;
use GuzzleHttp\ClientInterface;

class RestGroups
{

  /**
   * @var ClientInterface
   */
  protected $httpClient;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  protected $userEntity;

  protected $group;
  /**
   *
   * @param ClientInterface $http_client
   *
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *
   * @param  EntityTypeManagerInterface $entity_type_manager
   *
   */
  public function __construct(ClientInterface $http_client, AccountInterface $current_user, EntityTypeManagerInterface $entity_type_manager) {
    $this->currentUser = $current_user;
    $this->httpClient = $http_client;
    $this->entityTypeManager = $entity_type_manager;
  }




  public function syncRoles($group_name, $account) {
      $msg = '';
      $this->setUser($account);
      if ($this->getUser()->hasRole($group_name)) {
        $msg = 'El usuario '.$account.' está sincronizado con su grupo '.$group_name;
      }
      else {
        $roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
        if (array_key_exists($group_name, $roles)){
          $this->getUser()->addRole($group_name);
          $this->getUser()->save();
          $msg = 'Se ha asociado el grupo '.$group_name.' al usuario '.$account;
        }
        else{
          $data = ['id' => $group_name, 'label' => $group_name];
          $role = Role::create($data);
          $role->save();
          $this->getUser()->addRole($group_name);
          $this->getUser()->save();
          $msg = 'Se ha creado el grupo '.$group_name.' y asociado al usuario '.$account;
        }
      }
      return $msg;
  }




  public function matchGroup($group_name, $account) {
    $user = $this->getUser();
    var_dump($user);


   $match = $this->entityTypeManager->getStorage('group')
      ->loadByProperties([
        'label' => $group_name,
      ]);
   if (!empty($match)){
     $group = reset($match);
     $this->setGroup($group);
     $this->setUser($account);
     if ($this->checkMember()){
       $this->syncRoleMember($group_name);
     }
     else{
       var_dump('NO SOY MIEMBRO');
       $this->addMemberToGroup($group_name);
       //TODO:le añado al grupo
     }
          //var_dump($group->getMembers());
   }
   else {
     var_dump('no lo encuentra');
     // no lo encuentra
     // creo el grupo y rol y asigno miembro
     //
   }
  }

  private function addMemberToGroup($group_name) {
    $roleMachineName = (strpos($group_name,'om_') !== FALSE) ? 'om-'.$group_name : 'tm-'.$group_name;
    $userCurrent = $this->getUser();
    $group = $this->getGroup();
    /*
    if ($group instanceof GroupInterface) {
      var_dump('ES $groupInterface ');
    }
    else{
      var_dump('NO ES $groupInterface ');
    }*/
    //var_dump($userCurrent);
    //$group->addMember($userCurrent);
    //$group->save();

    var_dump('MIEMBRO AÑADIDO');
  }

  private function syncRoleMember($group_name) {
    $member = $this->group->getMember($this->getUser());
    $roleMachineName = (strpos($group_name,'om_') !== FALSE) ? 'om-'.$group_name : 'tm-'.$group_name;
    if (!array_key_exists($roleMachineName, $member->getRoles())){
      var_dump('no tiene el role');
      $this->createRoleGroup($group_name, $roleMachineName);
    }
  }

  private function createRoleGroup($label,$machineName) {
    $member = $this->group->getMember($this->getUser());
    $group_content = $member->getGroupContent();
    //TODO: los roles deben estar creados
    $group_content->group_roles->appendItem(['target_id' => $machineName]);
    $group_content->save();
  }

  private function checkMember() {
    $group = $this->getGroup();
    if ($member = $group->getMember($this->getUser())) {
      var_dump('PERTENECE AL GRUPO');
      return true;
    }
    else {
      var_dump('NO PERTENECE AL GRUPO');
      return false;
    }
  }

  private function setGroup($group){
    $this->group = $group;
  }

  private function getGroup(){
    return $this->group;
  }

  private function getUser(){
    return User::load(\Drupal::currentUser()->id());
  }

  private function setUser($userName) {
    $user = $this->entityTypeManager->getStorage('user')->loadByProperties(['name' => $userName]);
    if (!empty($user)) {
      // encuentra el usuario
      $this->userEntity = reset($user);
    }
    else{
      var_dump('Usuario no encontrado');
      // no encuentra el usuario
    }
  }

  public function getGroups()
  {
    $request = $this->httpClient->request('GET', 'http://192.168.69.13:1880/rest/v1/groups');
    if ($request->getStatusCode() != 200) {
      // error
      return false;
    }
    else {
      $posts = $request->getBody()->getContents();
      $data = Json::decode($posts);
      return $data;
    }
  }

}
