<?php

namespace Drupal\emergya\Services;


use Drupal\Component\Serialization\Json;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\group\Entity\Group;
use Drupal\group\Entity\GroupInterface;
use Drupal\user\Entity\Role;
use Drupal\user\Entity\User;
use Drupal\user\UserInterface;
use GuzzleHttp\ClientInterface;

class RoleGroups
{

  /**
   * @var ClientInterface
   */
  protected $httpClient;


  protected $currentUser;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * @var MessengerInterface
   */
  protected $messenger;

  protected $group;
  /**
   *
   * @param ClientInterface $http_client
   *
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *
   * @param  EntityTypeManagerInterface $entity_type_manager
   *
   * @param MessengerInterface $messenger
   */
  public function __construct(ClientInterface $http_client, EntityTypeManagerInterface $entity_type_manager, MessengerInterface $messenger) {
    $this->httpClient = $http_client;
    $this->entityTypeManager = $entity_type_manager;
    $this->messenger = $messenger;
  }

  public function syncRoles($group_name, $account) {
      $msg = '';
      if ($account->hasRole($group_name)) {
        $msg = 'El usuario '.$account->getAccountName().' está sincronizado con su grupo '.$group_name;
      }
      else {
        $roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
        if (array_key_exists($group_name, $roles)){
          $account->addRole($group_name);
          $account->save();
          $msg = 'Se ha asociado el rol '.$group_name.' al usuario '.$account->getAccountName();
        }
        else{
          $data = ['id' => $group_name, 'label' => $group_name];
          $role = Role::create($data);
          $role->grantPermission('view my groups');
          $role->save();
          $account->addRole($group_name);
          $account->save();
          $msg = 'Se ha creado el rol '.$group_name.' y asociado al usuario '.$account->getAccountName();
        }
      }
      return $msg;
  }

  /**
   * @param $group_name
   * @return void
   */
  public function matchGroup($group_name) {
    $match = $this->searchGroup($group_name);
   if (!empty($match)){
     $this->setGroup($match);
     if (!$this->checkMember()){
       $this->addMemberToGroup($group_name);
     }
   }
   else {
     $this->createGroup($group_name);
     $this->addMemberToGroup($group_name);
   }
   $msg = $this->syncRoles($group_name,$this->getUser()->getAccountName());
   $this->messenger->addMessage($msg);
  }


  private function createGroup($group_name){
    $type = (strpos($group_name,'om_') !== FALSE) ? 'om' : 'tm';
    $group_to_create= $this->entityTypeManager->getStorage('group')->create(['type' => $type]);
    $group_to_create->set('label', $group_name);
    $owner = $this->entityTypeManager->getStorage('user')->load(1);
    $group_to_create->setOwner($owner);
    $group_to_create->save();
    $this->setGroup($this->searchGroup($group_name));
  }

  private function addMemberToGroup($group_name) {
    $roleMachineName = (strpos($group_name,'om_') !== FALSE) ? 'om-'.$group_name : 'tm-'.$group_name;
    $group = $this->getGroup();
   // $group->addMember($this->getUser(),['group_roles' => [$roleMachineName]]);
    $group->addMember($this->getUser());
    $group->save();
    $this->messenger->addMessage('Se ha añadido al usuario ' . $this->getUser()->getAccountName() . ' al grupo ' . $group_name);
  }

  private function syncRoleMember($roleMachineName) {
    $member = $this->group->getMember($this->getUser());
    if (!array_key_exists($roleMachineName, $member->getRoles())){
      $this->createRoleGroup($roleMachineName);
    }
  }

  private function searchGroup($group_name){
   $match = $this->entityTypeManager->getStorage('group')
      ->loadByProperties([
        'label' => $group_name,
      ]);
   if (!empty($match)) {
     return reset($match);
   }
   return false;
  }


  private function createRoleGroup($machineName) {
    $member = $this->group->getMember($this->getUser());
    $group_content = $member->getGroupContent();
    $group_content->group_roles->appendItem(['target_id' => $machineName]);
    $group_content->save();
  }

  private function checkMember() {
    $group = $this->getGroup();
    if ($isMember = $group->getMember($this->getUser())) {
      return true;
    }
    else {
      return false;
    }
  }
















  private function setGroup($group){
    $this->group = $group;
  }
  private function getGroup(){
    return $this->group;
  }
  private function getUser(){
    return $this->currentUser;
  }

  public function getGroups()
  {
    $request = $this->httpClient->request('GET', 'http://192.168.69.13:1880/rest/v1/groups');
    if ($request->getStatusCode() != 200) {
      // error
      return false;
    }
    else {
      $posts = $request->getBody()->getContents();
      $data = Json::decode($posts);
      return $data;
    }
  }

}
