<?php

namespace Drupal\gnetwork\Plugin\Field\FieldFormatter;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\gnetwork\Plugin\Field\FieldType\G6SyncItem;

/**
 * Plugin implementation of the 'gnet_g6sync_key_value' formatter.
 *
 * @FieldFormatter(
 *   id = "gnet_g6sync_key_value",
 *   label = @Translation("Key-value"),
 *   field_types = {"gnet_g6sync"}
 * )
 */
class G6SyncKeyValueFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $element = [];

    foreach ($items as $delta => $item) {

      $table = [
        '#type' => 'table',
      ];

      // User created.
      if ($item->uid_created) {
        $allowed_values = G6SyncItem::allowedUserCreatedValues();

        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('User created'),
              ],
            ],
            [
              'data' => [
                '#markup' => $allowed_values[$item->uid_created],
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // User changed.
      if ($item->uid_changed) {
        $allowed_values = G6SyncItem::allowedUserChangedValues();

        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('User changed'),
              ],
            ],
            [
              'data' => [
                '#markup' => $allowed_values[$item->uid_changed],
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Created on.
      if ($item->ts_created) {
        $date = DrupalDateTime::createFromFormat('Y-m-d\TH:i:s', $item->ts_created);
        $date_formatter = \Drupal::service('date.formatter');
        $timestamp = $date->getTimestamp();
        $allowed_values = G6SyncItem::allowedCreatedOnValues();
        $formatted_date = $allowed_values[$item->ts_created];
        $iso_date = $date_formatter->format($timestamp, 'custom', 'Y-m-d\TH:i:s') . 'Z';

        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Created on'),
              ],
            ],
            [
              'data' => [
                '#theme' => 'time',
                '#text' => $formatted_date,
                '#html' => FALSE,
                '#attributes' => [
                  'datetime' => $iso_date,
                ],
                '#cache' => [
                  'contexts' => [
                    'timezone',
                  ],
                ],
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Changed on.
      if ($item->ts_changed) {
        $date = DrupalDateTime::createFromFormat('Y-m-d\TH:i:s', $item->ts_changed);
        $date_formatter = \Drupal::service('date.formatter');
        $timestamp = $date->getTimestamp();
        $allowed_values = G6SyncItem::allowedChangedOnValues();
        $formatted_date = $allowed_values[$item->ts_changed];
        $iso_date = $date_formatter->format($timestamp, 'custom', 'Y-m-d\TH:i:s') . 'Z';

        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Changed on'),
              ],
            ],
            [
              'data' => [
                '#theme' => 'time',
                '#text' => $formatted_date,
                '#html' => FALSE,
                '#attributes' => [
                  'datetime' => $iso_date,
                ],
                '#cache' => [
                  'contexts' => [
                    'timezone',
                  ],
                ],
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      $element[$delta] = $table;

    }

    return $element;
  }

}
