<?php

namespace Drupal\gnetwork\Plugin\Field\FieldFormatter;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\gnetwork\Plugin\Field\FieldType\G6SyncItem;

/**
 * Plugin implementation of the 'gnet_g6sync_table' formatter.
 *
 * @FieldFormatter(
 *   id = "gnet_g6sync_table",
 *   label = @Translation("Table"),
 *   field_types = {"gnet_g6sync"}
 * )
 */
class G6SyncTableFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $header[] = '#';
    $header[] = $this->t('User created');
    $header[] = $this->t('User changed');
    $header[] = $this->t('Created on');
    $header[] = $this->t('Changed on');

    $table = [
      '#type' => 'table',
      '#header' => $header,
    ];

    foreach ($items as $delta => $item) {
      $row = [];

      $row[]['#markup'] = $delta + 1;

      if ($item->uid_created) {
        $allowed_values = G6SyncItem::allowedUserCreatedValues();
        $row[]['#markup'] = $allowed_values[$item->uid_created];
      }
      else {
        $row[]['#markup'] = '';
      }

      if ($item->uid_changed) {
        $allowed_values = G6SyncItem::allowedUserChangedValues();
        $row[]['#markup'] = $allowed_values[$item->uid_changed];
      }
      else {
        $row[]['#markup'] = '';
      }

      if ($item->ts_created) {
        $date = DrupalDateTime::createFromFormat('Y-m-d\TH:i:s', $item->ts_created);
        $date_formatter = \Drupal::service('date.formatter');
        $timestamp = $date->getTimestamp();
        $allowed_values = G6SyncItem::allowedCreatedOnValues();
        $formatted_date = $allowed_values[$item->ts_created];
        $iso_date = $date_formatter->format($timestamp, 'custom', 'Y-m-d\TH:i:s') . 'Z';
        $row[] = [
          '#theme' => 'time',
          '#text' => $formatted_date,
          '#html' => FALSE,
          '#attributes' => [
            'datetime' => $iso_date,
          ],
          '#cache' => [
            'contexts' => [
              'timezone',
            ],
          ],
        ];
      }
      else {
        $row[]['#markup'] = '';
      }

      if ($item->ts_changed) {
        $date = DrupalDateTime::createFromFormat('Y-m-d\TH:i:s', $item->ts_changed);
        $date_formatter = \Drupal::service('date.formatter');
        $timestamp = $date->getTimestamp();
        $allowed_values = G6SyncItem::allowedChangedOnValues();
        $formatted_date = $allowed_values[$item->ts_changed];
        $iso_date = $date_formatter->format($timestamp, 'custom', 'Y-m-d\TH:i:s') . 'Z';
        $row[] = [
          '#theme' => 'time',
          '#text' => $formatted_date,
          '#html' => FALSE,
          '#attributes' => [
            'datetime' => $iso_date,
          ],
          '#cache' => [
            'contexts' => [
              'timezone',
            ],
          ],
        ];
      }
      else {
        $row[]['#markup'] = '';
      }

      $table[$delta] = $row;
    }

    return [$table];
  }

}
