<?php

namespace Drupal\gnetwork\Plugin\Field\FieldWidget;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\gnetwork\Plugin\Field\FieldType\G6SyncItem;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'gnet_g6sync' field widget.
 *
 * @FieldWidget(
 *   id = "gnet_g6sync",
 *   label = @Translation("g6 Sync"),
 *   field_types = {"gnet_g6sync"},
 * )
 */
class G6SyncWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return ['foo' => 'bar'] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = $this->t('Foo: @foo', ['@foo' => $settings['foo']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $element['uid_created'] = [
      '#type' => 'select',
      '#title' => $this->t('User created'),
      '#options' => ['' => $this->t('- None -')] + G6SyncItem::allowedUserCreatedValues(),
      '#default_value' => isset($items[$delta]->uid_created) ? $items[$delta]->uid_created : NULL,
    ];

    $element['uid_changed'] = [
      '#type' => 'select',
      '#title' => $this->t('User changed'),
      '#options' => ['' => $this->t('- None -')] + G6SyncItem::allowedUserChangedValues(),
      '#default_value' => isset($items[$delta]->uid_changed) ? $items[$delta]->uid_changed : NULL,
    ];

    $element['ts_created'] = [
      '#type' => 'select',
      '#title' => $this->t('Created on'),
      '#options' => ['' => $this->t('- None -')] + G6SyncItem::allowedCreatedOnValues(),
      '#default_value' => isset($items[$delta]->ts_created) ? $items[$delta]->ts_created : NULL,
    ];

    $element['ts_changed'] = [
      '#type' => 'select',
      '#title' => $this->t('Changed on'),
      '#options' => ['' => $this->t('- None -')] + G6SyncItem::allowedChangedOnValues(),
      '#default_value' => isset($items[$delta]->ts_changed) ? $items[$delta]->ts_changed : NULL,
    ];

    $element['#theme_wrappers'] = ['container', 'form_element'];
    $element['#attributes']['class'][] = 'gnet-g6sync-elements';
    $element['#attached']['library'][] = 'gnetwork/gnet_g6sync';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      if ($value['uid_created'] === '') {
        $values[$delta]['uid_created'] = NULL;
      }
      if ($value['uid_changed'] === '') {
        $values[$delta]['uid_changed'] = NULL;
      }
      if ($value['ts_created'] === '') {
        $values[$delta]['ts_created'] = NULL;
      }
      if ($value['ts_created'] instanceof DrupalDateTime) {
        $values[$delta]['ts_created'] = $value['ts_created']->format('Y-m-d\TH:i:s');
      }
      if ($value['ts_changed'] === '') {
        $values[$delta]['ts_changed'] = NULL;
      }
      if ($value['ts_changed'] instanceof DrupalDateTime) {
        $values[$delta]['ts_changed'] = $value['ts_changed']->format('Y-m-d\TH:i:s');
      }
    }
    return $values;
  }

}
