<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'guifi_email_labeled_key_value' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_email_labeled_key_value",
 *   label = @Translation("Key-value"),
 *   field_types = {"guifi_email_labeled"}
 * )
 */
class EmailLabeledKeyValueFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $element = [];

    foreach ($items as $delta => $item) {

      $table = [
        '#type' => 'table',
      ];

      // email.
      if ($item->email) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('email'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->email,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Label.
      if ($item->label) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Label'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->label,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      $element[$delta] = $table;

    }

    return $element;
  }

}
