<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'guifi_phone_labeled_default' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_phone_labeled_default",
 *   label = @Translation("Default"),
 *   field_types = {"guifi_phone_labeled"}
 * )
 */
class PhoneLabeledDefaultFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    foreach ($items as $delta => $item) {

      if ($item->number) {
        $element[$delta]['number'] = [
          '#type' => 'item',
          '#title' => $this->t('number'),
          'content' => [
            '#type' => 'link',
            '#title' => $item->number,
            '#url' => Url::fromUri('tel:' . rawurlencode(preg_replace('/\s+/', '', $item->number))),
          ],
        ];
      }

      $element[$delta]['sms'] = [
        '#type' => 'item',
        '#title' => $this->t('SMS texts'),
        '#markup' => $item->sms ? $this->t('Yes') : $this->t('No'),
      ];

      if ($item->label) {
        $element[$delta]['label'] = [
          '#type' => 'item',
          '#title' => $this->t('Label'),
          '#markup' => $item->label,
        ];
      }

    }

    return $element;
  }

}
