<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'guifi_phone_labeled_key_value' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_phone_labeled_key_value",
 *   label = @Translation("Key-value"),
 *   field_types = {"guifi_phone_labeled"}
 * )
 */
class PhoneLabeledKeyValueFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $element = [];

    foreach ($items as $delta => $item) {

      $table = [
        '#type' => 'table',
      ];

      // number.
      if ($item->number) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('number'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->number,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // SMS texts.
      if ($item->sms) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('SMS texts'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->sms ? $this->t('Yes') : $this->t('No'),
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Label.
      if ($item->label) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Label'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->label,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      $element[$delta] = $table;

    }

    return $element;
  }

}
