<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'guifi_sync_track_default' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_sync_track_default",
 *   label = @Translation("Default"),
 *   field_types = {"guifi_sync_track"}
 * )
 */
class SyncTrackDefaultFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return ['foo' => 'bar'] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = $this->t('Foo: @foo', ['@foo' => $settings['foo']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    foreach ($items as $delta => $item) {

      if ($item->synctrack_source) {
        $element[$delta]['synctrack_source'] = [
          '#type' => 'item',
          '#title' => $this->t('Source'),
          '#markup' => $item->synctrack_source,
        ];
      }

      if ($item->synctrack_id) {
        $element[$delta]['synctrack_id'] = [
          '#type' => 'item',
          '#title' => $this->t('Id'),
          '#markup' => $item->synctrack_id,
        ];
      }

      if ($item->synctrack_when) {
        $date = DrupalDateTime::createFromFormat('Y-m-d\TH:i:s', $item->synctrack_when);
        // @DCG: Consider injecting the date formatter service.
        // @codingStandardsIgnoreStart
        $date_formatter = \Drupal::service('date.formatter');
        // @codingStandardsIgnoreStart
        $timestamp = $date->getTimestamp();
        $formatted_date = $date_formatter->format($timestamp, 'long');
        $iso_date = $date_formatter->format($timestamp, 'custom', 'Y-m-d\TH:i:s') . 'Z';
        $element[$delta]['synctrack_when'] = [
          '#type' => 'item',
          '#title' => $this->t('Last sync'),
          'content' => [
            '#theme' => 'time',
            '#text' => $formatted_date,
            '#html' => FALSE,
            '#attributes' => [
              'datetime' => $iso_date,
            ],
            '#cache' => [
              'contexts' => [
                'timezone',
              ],
            ],
          ],
        ];
      }

    }

    $element += array(
      '#type' => 'fieldset',
      '#attributes' =>array('class' => array('container-block')),
    );

    return $element;
  }

}
