<?php

namespace Drupal\guifi\Plugin\Field\FieldType;

use Drupal\Component\Utility\Random;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Render\Element\Email;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'guifi_email_labeled' field type.
 *
 * @FieldType(
 *   id = "guifi_email_labeled",
 *   label = @Translation("Email (labeled)"),
 *   category = @Translation("General"),
 *   default_widget = "guifi_email_labeled",
 *   default_formatter = "guifi_email_labeled_default"
 * )
 */
class EmailLabeledItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if ($this->email !== NULL) {
      return FALSE;
    }
    elseif ($this->label !== NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {

    $properties['email'] = DataDefinition::create('email')
      ->setLabel(t('email'));
    $properties['label'] = DataDefinition::create('string')
      ->setLabel(t('Label'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();

    // @todo Add more constraints here.
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {

    $columns = [
      'email' => [
        'type' => 'varchar',
        'length' => Email::EMAIL_MAX_LENGTH,
      ],
      'label' => [
        'type' => 'varchar',
        'length' => 255,
      ],
    ];

    $schema = [
      'columns' => $columns,
      // @DCG Add indexes here if necessary.
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {

    $random = new Random();

    $values['email'] = strtolower($random->name()) . '@example.com';

    $values['label'] = $random->word(mt_rand(1, 255));

    return $values;
  }

}
