<?php

namespace Drupal\guifi\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'guifi_sync' field type.
 *
 * @FieldType(
 *   id = "guifi_sync",
 *   label = @Translation("g66 Sync"),
 *   category = @Translation("General"),
 *   default_widget = "guifi_sync",
 *   default_formatter = "guifi_sync_default"
 * )
 */
class G66SyncItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    $settings = ['foo' => 'example'];
    return $settings + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    $settings = $this->getSettings();

    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
      '#disabled' => $has_data,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    $settings = ['bar' => 'example'];
    return $settings + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();

    $element['bar'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['bar'],
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if ($this->created_by !== NULL) {
      return FALSE;
    }
    elseif ($this->created_on !== NULL) {
      return FALSE;
    }
    elseif ($this->changed_by !== NULL) {
      return FALSE;
    }
    elseif ($this->changed_on !== NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {

    $properties['created_by'] = DataDefinition::create('integer')
      ->setLabel(t('Created By'));
    $properties['created_on'] = DataDefinition::create('datetime_iso8601')
      ->setLabel(t('Created On'));
    $properties['changed_by'] = DataDefinition::create('integer')
      ->setLabel(t('Changed By'));
    $properties['changed_on'] = DataDefinition::create('datetime_iso8601')
      ->setLabel(t('Changed On'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();

    // @todo Add more constraints here.
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {

    $columns = [
      'created_by' => [
        'type' => 'int',
        'size' => 'normal',
      ],
      'created_on' => [
        'type' => 'varchar',
        'length' => 20,
      ],
      'changed_by' => [
        'type' => 'int',
        'size' => 'normal',
      ],
      'changed_on' => [
        'type' => 'varchar',
        'length' => 20,
      ],
    ];

    $schema = [
      'columns' => $columns,
      // @DCG Add indexes here if necessary.
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {

    $values['created_by'] = mt_rand(-1000, 1000);

    $timestamp = \Drupal::time()->getRequestTime() - mt_rand(0, 86400 * 365);
    $values['created_on'] = gmdate('Y-m-d\TH:i:s', $timestamp);

    $values['changed_by'] = mt_rand(-1000, 1000);

    $timestamp = \Drupal::time()->getRequestTime() - mt_rand(0, 86400 * 365);
    $values['changed_on'] = gmdate('Y-m-d\TH:i:s', $timestamp);

    return $values;
  }

}
