<?php

namespace Drupal\guifi\Plugin\Field\FieldWidget;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'guifi_sync' field widget.
 *
 * @FieldWidget(
 *   id = "guifi_sync",
 *   label = @Translation("g66 Sync"),
 *   field_types = {"guifi_sync"},
 * )
 */
class G66SyncWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return ['foo' => 'bar'] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = $this->t('Foo: @foo', ['@foo' => $settings['foo']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $element['created_by'] = [
      '#type' => 'number',
      '#title' => $this->t('Created By'),
      '#default_value' => isset($items[$delta]->created_by) ? $items[$delta]->created_by : NULL,
    ];

    $element['created_on'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Created On'),
      '#default_value' => NULL,
    ];
    if (isset($items[$delta]->created_on)) {
      $element['created_on']['#default_value'] = DrupalDateTime::createFromFormat(
        'Y-m-d\TH:i:s',
        $items[$delta]->created_on,
        'UTC'
      );
    }

    $element['changed_by'] = [
      '#type' => 'number',
      '#title' => $this->t('Changed By'),
      '#default_value' => isset($items[$delta]->changed_by) ? $items[$delta]->changed_by : NULL,
    ];

    $element['changed_on'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Changed On'),
      '#default_value' => NULL,
    ];
    if (isset($items[$delta]->changed_on)) {
      $element['changed_on']['#default_value'] = DrupalDateTime::createFromFormat(
        'Y-m-d\TH:i:s',
        $items[$delta]->changed_on,
        'UTC'
      );
    }

    $element['#theme_wrappers'] = ['container', 'form_element'];
    $element['#attributes']['class'][] = 'guifi-sync-elements';
    $element['#attached']['library'][] = 'guifi/guifi_sync';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      if ($value['created_by'] === '') {
        $values[$delta]['created_by'] = NULL;
      }
      if ($value['created_on'] === '') {
        $values[$delta]['created_on'] = NULL;
      }
      if ($value['created_on'] instanceof DrupalDateTime) {
        $values[$delta]['created_on'] = $value['created_on']->format('Y-m-d\TH:i:s');
      }
      if ($value['changed_by'] === '') {
        $values[$delta]['changed_by'] = NULL;
      }
      if ($value['changed_on'] === '') {
        $values[$delta]['changed_on'] = NULL;
      }
      if ($value['changed_on'] instanceof DrupalDateTime) {
        $values[$delta]['changed_on'] = $value['changed_on']->format('Y-m-d\TH:i:s');
      }
    }
    return $values;
  }

}
