<?php

namespace Drupal\guifi\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'guifi_labeled_phone' field widget.
 *
 * @FieldWidget(
 *   id = "guifi_labeled_phone",
 *   label = @Translation("Labeled phone"),
 *   field_types = {"guifi_labeled_phone"},
 * )
 */
class LabeledPhoneWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return ['foo' => 'bar'] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = $this->t('Foo: @foo', ['@foo' => $settings['foo']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $element['phone_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#default_value' => isset($items[$delta]->phone_label) ? $items[$delta]->phone_label : NULL,
      '#size' => 20,
    ];

    $element['phone_number'] = [
      '#type' => 'tel',
      '#title' => $this->t('Number'),
      '#default_value' => isset($items[$delta]->phone_number) ? $items[$delta]->phone_number : NULL,
      '#size' => 20,
    ];

    $element['#theme_wrappers'] = ['container', 'form_element'];
    $element['#attributes']['class'][] = 'container-inline';
    $element['#attributes']['class'][] = 'guifi-labeled-phone-elements';
    $element['#attached']['library'][] = 'guifi/guifi_labeled_phone';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      if ($value['phone_label'] === '') {
        $values[$delta]['phone_label'] = NULL;
      }
      if ($value['phone_number'] === '') {
        $values[$delta]['phone_number'] = NULL;
      }
    }
    return $values;
  }

}
