<?php

namespace Drupal\guifi\Plugin\Field\FieldWidget;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'guifi_sync_track' field widget.
 *
 * @FieldWidget(
 *   id = "guifi_sync_track",
 *   label = @Translation("Sync track"),
 *   field_types = {"guifi_sync_track"},
 * )
 */
class SyncTrackWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return ['foo' => 'bar'] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = $this->t('Foo: @foo', ['@foo' => $settings['foo']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $element['synctrack_source'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Source'),
      '#default_value' => isset($items[$delta]->synctrack_source) ? $items[$delta]->synctrack_source : NULL,
    ];

    $element['synctrack_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Id'),
      '#default_value' => isset($items[$delta]->synctrack_id) ? $items[$delta]->synctrack_id : NULL,
    ];

    $element['synctrack_when'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Last sync'),
      '#default_value' => NULL,
    ];
    if (isset($items[$delta]->synctrack_when)) {
      $element['synctrack_when']['#default_value'] = DrupalDateTime::createFromFormat(
        'Y-m-d\TH:i:s',
        $items[$delta]->synctrack_when,
        'UTC'
      );
    }

    $element['#theme_wrappers'] = ['container', 'form_element'];
    $element['#attributes']['class'][] = 'guifi-sync-track-elements';
    $element['#attached']['library'][] = 'guifi/guifi_sync_track';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      if ($value['synctrack_source'] === '') {
        $values[$delta]['synctrack_source'] = NULL;
      }
      if ($value['synctrack_id'] === '') {
        $values[$delta]['synctrack_id'] = NULL;
      }
      if ($value['synctrack_when'] === '') {
        $values[$delta]['synctrack_when'] = NULL;
      }
      if ($value['synctrack_when'] instanceof DrupalDateTime) {
        $values[$delta]['synctrack_when'] = $value['synctrack_when']->format('Y-m-d\TH:i:s');
      }
    }
    return $values;
  }

}
